GOOF----LE-8-2.0W      ]  4  hE
      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  ftw	 		g  filenameS	
f  
ice-9/ftw.scm	g  importsS	g  match	
 	
 	g  vlist	 	 	g  srfi	g  srfi-1	 	 	 	g  exportsS	g  nftw	g  file-system-fold	g  file-system-tree	g  scandir	 	g  	autoloadsS	g  i18n	 	 g  string-locale<?	!  	"! 	#g  set-current-module	$# 	%# 	&g  opendir	'g  eof-object?	(g  closedir	)g  readdir	*g  string=?	+f  .	,f  ..	-g  directory-files	.f   	/g  	substring	0g  
string-length	1g  
string-append	2f  /	3g  pathify	4g  char=?	5g  
string-ref	6g  abs?	7g  make-hash-table	8g  	hashv-ref	9g  stat:dev	:g  stat:ino	;g  
hashv-set!	<g  
visited?-proc	=g  getuid	>g  getgid	?g  
stat:perms	@g  stat:uid	Ag  stat:gid	Bg  stat-dir-readable?-proc	Cg  memq	Dg  depth	Eg  directory-processed	Fg  	directory	Gg  
nftw-style	Hg  
stale-symlink	Ig  symlink	Jg  physical	Kg  catch	LK 	MK 	Ng  lstat	Og  	stat:type	Pg  stat	Qg  directory-not-readable	Rg  regular	Sg  invalid-stat	Tg  stat&flag-proc	Ug  clean	Vg  	hash-size	Wg  throw	Xg  ftw-early-exit	Yg  for-each	Zg  getcwd	[g  mount	\g  chdir	]g  nftw-early-exit	^g  make-syntax-transformer	_^ 	`^ 	ag  errno-if-exception	bg  macro	cg  $sc-dispatch	dc 	ec 	fg  any	gff 	hg  
syntax-object	ig  top	ji 	kg  ribcage	lg  dummy	mg  expr	nlm 	og  m-cL@SLmETjwqZgirBySRP$c-3674	poi 	qpj 	rf  l-cL@SLmETjwqZgirBySRP$c-3679	sf  l-cL@SLmETjwqZgirBySRP$c-3680	trs 	uknqt 	vk 	wg  x	xw 	yp 	zf  l-cL@SLmETjwqZgirBySRP$c-3676	{z 	|kxy{ 	}juv| 	~g  hygiene	~  hK}  g  quote h}  g  system-error h}    g  lambda h}  g  args h}  g  system-error-errno h}        g  syntax-violation     f  -source expression failed to match any pattern g  integer? g  vhash-assoc g  
vhash-cons g  directory-stream? g  fold g  cons g  
alist-cons g  
vlist-null g  basename g  error 
  
  f  no matching pattern   g  const g  and=> g  sortC 5      hK     ]4	
"5	 4% >  "  G   &'()*+,      h   s  ]!4 5"  `45$  4>  "  G  C4545$  "  	45$  "  "45" k      g  dir
		 g  
dir-stream			 g  new			o g  acc			o g  t		?	X  g  filenamef  
ice-9/ftw.scm
 
	 			 		 		 	
	 		 		0 		7 		; 	"	? 		? 		M 		Q 	"	U 		\ 		g 		o 	
	o 		p 		w 		 	 		  g  nameg  directory-files C-R*./012  hh   J  -  1  3 "  J(  -45$  "  $  C45645" "     B      g  nodes
			c g  nodes	
	W g  result		
	W g  t		'	@  g  filenamef  
ice-9/ftw.scm
 
	
 		 		 		 		 		  		" 	&	' 		8 	 	@ 		C 		D 		J 	0	M 	4	O 		W 		W 		[ 		c 	 			c


  g  nameg  pathify C3R45   h   z   ]/4 
56r       g  filename
		  g  filenamef  
ice-9/ftw.scm
 
	 		 	 		  g  nameg  abs? C6R789:7;  h   !  ] $  y4L 4 554 5HJ$  "  $4L5K4L 4 5J>  "  G  4J5$  C4J>  "  G  CC           g  s
	  g  ino-hash	  g  ino		  g  t		#	V g  t		_   g  filenamef  
ice-9/ftw.scm
 		 			 		 	/	 		 		 		# 	
	0 	"	8 		9 		> 	(	K 		W 		_ 	
	k 	 	    C    h      ]	4	5 O C          g  size
		 g  dev-hash			  g  filenamef  
ice-9/ftw.scm
 
	 			 	 		  g  nameg  
visited?-proc C<R=>?@A  hh   ,  ]4 5L 4 5$  
 "  $  CL4 5$  
	 "  $  C
	C       $      g  s
		a g  perms			a g  t		'	a g  t		M	a  g  filenamef  
ice-9/ftw.scm
													 	)	!	$	"		'		5		<		@		F	)	G	$	H		M		^	)	_	$	`	 		a   C h       ]45 45 O C             g  uid
		 g  gid		 g  uid			 g  gid			  g  filenamef  
ice-9/ftw.scm
 
	 	
	 	
	 	 			  g  nameg  stat-dir-readable?-proc CBRCDEFGHIJMN       h   J   ] L 6B       g  filenamef  
ice-9/ftw.scm
			# 		
   C    h   V   -  1  3 C     N       g  args
			  g  filenamef  
ice-9/ftw.scm
	 			


   CIOP        h   J   ] L 6B       g  filenamef  
ice-9/ftw.scm
			3 		
   C    h   V   -  1  3 C     N       g  args
			  g  filenamef  
ice-9/ftw.scm
	 			


   CFQRS       h     ]4 O 5$  45&  Z4 O 5$  =L$  D45&  4L5$  L"  	"  
DL D45&  4L5$  L"  	"  
DD       g  name
	  g  s	  g  s-follow		5  g  type		R	x g  type	    g  filenamef  
ice-9/ftw.scm
												&		'		5		= 		C"		G#	"	I#		L	"	R		V	!	\		]	 	g		o	 	u		z%	 !	 	" 	 	! 	 	  	 	  	 &	 	 	 #	    C 
     hP     - 1 3 45$  "  45$  "  45	 O C      g  
dir-readable?
			P g  
control-flags			P g  directory-flag			P g  stale-symlink-flag		5	P g  	physical?		@	P  g  filenamef  
ice-9/ftw.scm

	
			#					
						!	!	%	'	)	!	-		/	!	5	!	5		8		<		@		@	 			P
  g  nameg  stat&flag-proc CTR045/ h0      ]	4 54/4 55$  	 
6 C           g  name
		, g  last-char-index	
	,  g  filenamef  
ice-9/ftw.scm
(
	)		
)		
)		
*		*		*		 *		)+	 
		,  g  nameg  clean CUR<CVTB=>WXFY3      h   g   ]L4L  56 _       g  child
		  g  filenamef  
ice-9/ftw.scm
<	#	=	)	=	% 		   C-    h   4  ]4L >  G 4L5$  C4L  5&  "  4>  "  G  &  $4 LO 4 5>  "  G  "   C,      g  fullname
	  g  s	
  g  flag		
  g  t		  g  ret		1   g  filenamef  
ice-9/ftw.scm
3		4	0	4		6		6		'7	&	17		:8		?9	!	C9	(	J9	!	T:	'	Z:		[;	"	g>	#	r;	" 	   g  nameg  go CKXU  h   S   ] L4L 56   K       g  filenamef  
ice-9/ftw.scm
A	
	A		
A	 		
   C   h   d   ]C   \       g  key
		 g  val		  g  filenamef  
ice-9/ftw.scm
B	
 			   C 
hp   v  - 1 3 445$  "   54445 45 55O Q 	
 O 6    n      g  filename
			l g  proc			l g  options				l g  t			+ g  visited?		-	l g  	stat&flag		C	l g  go		P	l  g  filenamef  
ice-9/ftw.scm
.
	
/		
/	)	/	/	/	)	/	"	-/		-/		01		32		62	.	;2	7	A2		C1		C/		P3		_@	
	l@	 			l	
	  g  nameg  ftw CRZMN    h   J   ] L 6B       g  filenamef  
ice-9/ftw.scm
F		F	, 		
   C    h   V   -  1  3 C     N       g  args
			  g  filenamef  
ice-9/ftw.scm
F	 			


   C9C[9      h   c   ]4 5L C   [       g  s
		
  g  filenamef  
ice-9/ftw.scm
I		I	'	I	$ 		
   C   h   Q   ]C    I       g  s
		  g  filenamef  
ice-9/ftw.scm
J	 		   C\6\/   h       ]

$  C4 
56        g  fullname
		 g  base		 g  t			  g  filenamef  
ice-9/ftw.scm
N		O	!	O		K	'	P	! 			   C\3/ h      ]4L 4 
556        g  fullname
		 g  base		  g  filenamef  
ice-9/ftw.scm
Q		S		
K	'	S		R	 			   Ch   j   ]C    b       g  fullname
		 g  base		  g  filenamef  
ice-9/ftw.scm
T	 			   C\        h   J   ] L 6B       g  filenamef  
ice-9/ftw.scm
V		V	' 		
   C    h   A   ] C    9       g  filenamef  
ice-9/ftw.scm
W	 		
   CD<VE   h   f   ] C^       g  flag
		  g  filenamef  
ice-9/ftw.scm
]		]	1	]	' 		   CF    h   f   ] C^       g  flag
		  g  filenamef  
ice-9/ftw.scm
^		^	1	^	' 		   CTB=>GY30     h       ]L4L 54L5L 6      z       g  child
		  g  filenamef  
ice-9/ftw.scm
p	.	q	4	r	8	r	4	t	4	q	0 		   C-W]30        h       ]L4L 54L5L 6      z       g  child
		  g  filenamef  
ice-9/ftw.scm
p	.	q	4	r	8	r	4	t	4	q	0 		   C   hh  ?  ]+4L >  G 4L5$  " 14L 5$  " L$  4L5$  &4 LO 4 5>  "  G  "   4L >  "  G  4L 54L>   "  G  &  "  4>  "  G  "  4L >  "  G  4L 54L>   "  G  &  "  4>  "  G  4L5$  &4 LO 4 5>  "  G  "   C     7      g  fullname
	c g  base	c g  level		c g  s		
a g  flag		
a g  t		[ g  t		/X g  ret	   g  ret	 $  	g  filenamef  
ice-9/ftw.scm
b		c	0	c		v		v		(w	"	/w		/v		Ax		Bn	-	Ln	(	Mo	-	[u	.	fo	-	sf	( h	3 h	( j	* k	* l	. l	5 l	. f	( h	3 h	( j	*	k	*l	.l	5l	.%n	-/n	(0o	->u	.Io	- $	c	  g  nameg  go CK]U       h   S   ] L4L 5

6 K       g  filenamef  
ice-9/ftw.scm
}		}	'	}	# 		
   C   h   d   ]C   \       g  key
		 g  val		  g  filenamef  
ice-9/ftw.scm
~	 			   C\ !      hH    - 1 3 45 4 O 5$  45"  	45$  O "  	4
5$  4 5$  "  
O "  4
5$  O "  45445		$  	"   	5	$  "  
4445 45 5?O 	
	Q 4 O 5
4 >  "  G  
C       g  filename
		G g  proc		G g  
control-flags			G g  od		G g  s			7 g  odev		7G g  	same-dev?		SG g  maybe-cd	 G g  
maybe-cd-back	 G g  depth-first?	 G g  t		   g  visited?		 G g  	has-kids?	
 G g  	stat&flag	 G g  go		G g  ret	
0G  g  filenamef  
ice-9/ftw.scm
D
	
E	
	E		F		F		'G		(G		7E		:H		>H		BH		FH		SE		VL		ZL		^L		bL		cM		mM	 E	 U	 U	" U	 U	 E	 X	 X	 X	 E	 Y	 Z	 Z	! Z	 Z	 Y	 E	 \	 E	 _	 `	 `	4 `	= `	 a	! _	 E		b	|	#|	0|	0|	3	 5		G	
	  g  nameg  nftw CR4`abeg h   ?   ] C    7       g  dummy
		 g  expr		  			   C  h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  
ice-9/ftw.scm

 		"  g  
macro-typeg  syntax-rulesg  patternsg  expr   C5aRN*.129:FOK&        h   J   ] M 6B       g  filenamef  
ice-9/ftw.scm
			- 		
   C        h   V   -  1  3  6 N       g  args
			  g  filenamef  
ice-9/ftw.scm
	 			


   C'(   h   n   ] LLMLL L 6    f       g  filenamef  
ice-9/ftw.scm
	,		4		4		4		4		. 		
   C       h    {   ]4L  LO >   6<      s       g  subdir
		 g  result+visited		  g  filenamef  
ice-9/ftw.scm
	&		( 			   C+,)     h   J   ] LL 6B       g  filenamef  
ice-9/ftw.scm
	%		9 		
   C        h   V   -  1  3  6 N       g  args
			  g  filenamef  
ice-9/ftw.scm
	% 			


   C     h(    ]EH45$   "  4 5K45$  L J6445455$  D	4
5& 4LJ5$ |4
O 544545545$ 5" 45$  :4>  "  G  4LO 	
54LJ5D45$  "  	45$  45	

	"4J54LO 545$  454L 	5

	"54
5	&  45	4
5
	"
454L	5

	"454LJ5
	"4L J5D4LJ5445455DLJ6             g  name
	! g  path	! g  dir-stat		! g  result		! g  visited		! g  	full-name		! g  dir	  g  visited	  g  entry	  g  result		  g  subdirs	
  g  r+v	   g  t	  g  child	< g  st	P  g  filenamef  
ice-9/ftw.scm
			
				
				
			#	
	&		0		;		<		?		F	$	M		Q		U		[		]		^		h		i	
	w		x	 	 	 	# 	 	 	
 	 	 	 	 	 	 	  	& 	  	 	# 	: 	# 	# 	 	 	+ 	 	
		+			1	2	%8	><	%<	?	%P	S	]	^	#e	#|	}	&	5		'	'	!	'	'	!		"	"	"								#			
!	 [	!	  g  nameg  loop C.K  h   J   ] LL 6B       g  filenamef  
ice-9/ftw.scm
			+ 		
   C        h   V   -  1  3  6 N       g  args
			  g  filenamef  
ice-9/ftw.scm
	 			


   C 	    hX   J  - . 	, 	3 
#  O 		 Q 		4O 56  B      g  enter?
		V g  leaf		V g  down			V g  up			V g  skip			V g  error			V g  init			V g  	file-name			V g  stat			V g  loop			%	V  
g  filenamef  
ice-9/ftw.scm

	%		>		?		V	 		V	  g  nameg  file-system-foldg  
documentationf Traverse the directory at FILE-NAME, recursively.  Enter
sub-directories only when (ENTER? PATH STAT RESULT) returns true.  When
a sub-directory is entered, call (DOWN PATH STAT RESULT), where PATH is
the path of the sub-directory and STAT the result of (stat PATH); when
it is left, call (UP PATH STAT RESULT).  For each file in a directory,
call (LEAF PATH STAT RESULT).  When ENTER? returns false, call (SKIP
PATH STAT RESULT).  When an `opendir' or STAT call raises an exception,
call (ERROR PATH STAT ERRNO RESULT), with ERRNO being the operating
system error number that was raised.

Return the result of these successive applications.
When FILE-NAME names a flat file, (LEAF PATH STAT INIT) is returned.
The optional STAT parameter defaults to `lstat'. CRh   `   ]C    X       g  n
		 g  s		  g  filenamef  
ice-9/ftw.scm
	. 			   CN        hP      ]$  ?$  &$  44 5 5C666       g  name
		P g  stat		P g  result			P g  w			H g  x			H  g  filenamef  
ice-9/ftw.scm
				"	
	%		0	4	4	
	7		<	 			P	  g  nameg  leaf C  hx     ]#$  g$  N$  ?$  &$  44 55C66666       g  name
		x g  stat		x g  result			x g  w			p g  x			p g  w		'	` g  x		'	`  g  filenamef  
ice-9/ftw.scm
				:	
	=		H	)	L	
	O		T	 			x	  g  nameg  up Ch      ]L  6             g  name
		
 g  stat		
 g  result			
  g  filenamef  
ice-9/ftw.scm
		
	 		
	  g  nameg  enter?* C       h      ]C        g  name
		 g  stat		 g  result			  g  filenamef  
ice-9/ftw.scm
		 	
	 	 			  g  nameg  down C*     h       ]4 L5$  CL  6           g  name
		 g  stat		 g  errno			 g  result			  g  filenamef  
ice-9/ftw.scm
			
		
			 			  g  nameg  error C  h   B   ] 6      :       g  filenamef  
ice-9/ftw.scm		 		

   C     h     - . , 3 
#  #  4O  O 	 5	
$  R(  G"   (  		(  C
66 $  (  C""6 6         g  	file-name
	  g  enter?	  g  stat		  g  leaf		(  g  up		(  g  v		K  g  failure		Q  g  w		b  g  failure		f  g  w			v   
g  filenamef  
ice-9/ftw.scm

	)		E	;	K	 	 	  g  nameg  file-system-treeg  
documentationf RReturn a tree of the form (FILE-NAME STAT CHILDREN ...) where STAT is
the result of (STAT FILE-NAME) and CHILDREN are similar structures for
each file contained in FILE-NAME when it designates a directory.  The
optional ENTER? predicate is invoked as (ENTER? NAME STAT) and should
return true to allow recursion into directory NAME; the default value is
a procedure that always returns #t.  When a directory does not match
ENTER?, it nonetheless appears in the resulting tree, only with zero
children.  The optional STAT parameter defaults to `lstat'.  Return #f
when FILE-NAME is not readable. CR *   h      ]$   L 6C             g  dir
		 g  stat		 g  result			  g  filenamef  
ice-9/ftw.scm
					 			  g  nameg  enter? C    h(      ]$  4 54L 5$  CCC        g  name
		' g  stat		' g  result			' g  basename			%  g  filenamef  
ice-9/ftw.scm
!		"			#		#							!	 		'	  g  nameg  leaf C+   h      ]4L 5$   CC          g  name
		 g  stat		 g  result			  g  filenamef  
ice-9/ftw.scm
%				&					
		&		&	 			  g  nameg  down C, h      ]4L 5$  CC         g  name
		 g  stat		 g  result			  g  filenamef  
ice-9/ftw.scm
(				)					
		)			 			  g  nameg  up C   h       ]4 54L 5$  CC        g  name
		 g  stat		 g  result			 g  basename				  g  filenamef  
ice-9/ftw.scm
+		-			-							 			  g  nameg  skip C*  h0      ]4L 5$  C4 54L 5$  CC        g  name*
		/ g  stat		/ g  errno			/ g  result			/ g  basename			/  g  filenamef  
ice-9/ftw.scm
/		0		0		2		2				&		+	 			/	  g  nameg  error CN   h   ^   ] L 6      V       g  files
		
  g  filenamef  
ice-9/ftw.scm
5			
6	 		
   C 
      hh     - . , 3 #  45#  4 O O O O 	O 
 O  5	O 6         g  name
		e g  select?		e g  entry<?			e  g  filenamef  
ice-9/ftw.scm

		+	'4			e4	 		e	  g  nameg  scandirg  
documentationf Return the list of the names of files contained in directory NAME
that match predicate SELECT? (by default, all files.)  The returned list
of file names is sorted according to ENTRY<?, which defaults to
`string-locale<?'.  Return #f when NAME is unreadable or is not a directory. CRC        g  m
		0  g  filenamef  
ice-9/ftw.scm	 
F 
 
 
7 
	 
;
L(
.
'gD
8
C.
K
 	K
   C6 